==> libstpk-0.9.16.0.tar.gz: libstpk-0.9.16.0/demo/BAROVOR/tmp2/phase3.f90 <==
program phase2
! ɸ줿 2 ʬۤΥǡ
! typhoon_analy ⥸塼ˤ Cart_conv_scal 롼Ѥ
! ǥ 2 Ÿ褹.

  use dcl
  use Dcl_Automatic
  use Math_Const
  use phys_const
  use typhoon_analy

  implicit none

  integer, parameter :: nx=360, ny=180, nr=500, nt=360
  real, parameter :: cmin=-1.0, cmax=1.0, contmin=-1.0, contmax=1.0

  integer :: i, j, k, l
  real :: x(nx), y(ny), r(nr), theta(nt), val1(nr,nt)
  real, dimension(nx,ny) :: val2, val3, val4, val5
  character(70) :: FONTNAME

!  call SWLSET( 'SYSFONT', .true. )
!  call SWSLFT( FONTNAME )
!  call SWCSET( 'FONTNAME', FONTNAME )

  val1=0.0

  r=(/(real(i)*0.01,i=1,nr)/)
  theta=(/(2.0*pi*real(i-1)/real(nt-1),i=1,nt)/)
!  r=(/(radius*(pi/180.0)*real(i)*0.1,i=1,nr)/)
  x=(/(real(i)*0.01,i=1,nx)/)
  y=(/(real(j)*0.01,j=1,ny)/)

  do j=1,nt
     do i=1,nr
        val1(i,j)=exp(-(r(i)**2))*cos(theta(j))
     end do
  end do

  do j=1,ny
     do i=1,nx
!        val3(i,j)=exp(-(((real(i)-0.5*real(nx))/real(nx))**2  &
!  &                    +((real(j)-0.5*real(ny))/real(ny))**2))
        val3(i,j)=exp(-((x(i)-x(nx/2))**2  &
  &                    +(y(j)-y(ny/2))**2))  &
  &              *((x(i)-x(nx/2))/(sqrt((x(i)-x(nx/2))**2+(y(j)-y(ny/2))**2)))
     end do
  end do

  call Cart_conv_scal( r, theta, val1, x, y, x(nx/2), y(ny/2), val2, axis='xy' )

  do j=ny/2-10,ny/2+10
     do i=nx/2,nx
        write(*,*) "val check", val2(i,j)
     end do
  end do

!------------- DCL
  call SGISET('IFONT',1 )
  CALL GLRSET( 'RMISS', -999.0 )
  CALL GLLSET( 'LMISS', .TRUE. )
  call UZFACT(0.75)

  call color_setting( 80, (/cmin, cmax/), min_tab=15999,  &
  &                   max_tab=95999, col_min=10, col_max=99 )

  call DclOpenGraphics(1)

  call Dcl_2D_cont_shade( 'Full',  &
  &                       x, y, val3, val3,  &
  &                       (/contmin, contmax/), (/cmin, cmax/),  &
  &                       (/'X (km)', 'Y (km)'/),  &
  &                       (/'(f6.1)', '(f6.1)'/),  &
  &                       c_num=(/10, 80/), no_tone=.true. )

  call Dcl_2D_cont_shade( 'Use-Cart',  &
  &                       x, y, val3, val2,  &
  &                       (/contmin, contmax/), (/cmin, cmax/),  &
  &                       (/'X (km)', 'Y (km)'/),  &
  &                       (/'(f6.1)', '(f6.1)'/),  &
  &                       c_num=(/10, 80/), no_tone=.true. )

  call DclCloseGraphics

end program

==> libstpk-0.9.20.0.tar.gz: libstpk-0.9.20.0/demo/BAROVOR/tmp2/phase3.f90 <==
program phase2
! ɸ줿 2 ʬۤΥǡ
! typhoon_analy ⥸塼ˤ Cart_conv_scal 롼Ѥ
! ǥ 2 Ÿ褹.

  use dcl
  use Dcl_Automatic
  use Math_Const
  use phys_const
  use typhoon_analy

  implicit none

  integer, parameter :: nx=360, ny=180, nr=500, nt=360
  real, parameter :: cmin=-1.0, cmax=1.0, contmin=-1.0, contmax=1.0

  integer :: i, j, k, l
  real :: x(nx), y(ny), r(nr), theta(nt), val1(nr,nt)
  real, dimension(nx,ny) :: val2, val3, val4, val5
  character(70) :: FONTNAME

!  call SWLSET( 'LSYSFNT', .true. )
!  call SWSLFT( FONTNAME )
!  call SWCSET( 'FONTNAME', FONTNAME )

  val1=0.0

  r=(/(real(i)*0.01,i=1,nr)/)
  theta=(/(2.0*pi*real(i-1)/real(nt-1),i=1,nt)/)
!  r=(/(radius*(pi/180.0)*real(i)*0.1,i=1,nr)/)
  x=(/(real(i)*0.01,i=1,nx)/)
  y=(/(real(j)*0.01,j=1,ny)/)

  do j=1,nt
     do i=1,nr
        val1(i,j)=exp(-(r(i)**2))*cos(theta(j))
     end do
  end do

  do j=1,ny
     do i=1,nx
!        val3(i,j)=exp(-(((real(i)-0.5*real(nx))/real(nx))**2  &
!  &                    +((real(j)-0.5*real(ny))/real(ny))**2))
        val3(i,j)=exp(-((x(i)-x(nx/2))**2  &
  &                    +(y(j)-y(ny/2))**2))  &
  &              *((x(i)-x(nx/2))/(sqrt((x(i)-x(nx/2))**2+(y(j)-y(ny/2))**2)))
     end do
  end do

  call Cart_conv_scal( r, theta, val1, x, y, x(nx/2), y(ny/2), val2, axis='xy' )

  do j=ny/2-10,ny/2+10
     do i=nx/2,nx
        write(*,*) "val check", val2(i,j)
     end do
  end do

!------------- DCL
  call SGISET('IFONT',1 )
  CALL GLRSET( 'RMISS', -999.0 )
  CALL GLLSET( 'LMISS', .TRUE. )
  call UZFACT(0.75)

  call color_setting( 80, (/cmin, cmax/), min_tab=15999,  &
  &                   max_tab=95999, col_min=10, col_max=99 )

  call DclOpenGraphics(1)

  call Dcl_2D_cont_shade( 'Full',  &
  &                       x, y, val3, val3,  &
  &                       (/contmin, contmax/), (/cmin, cmax/),  &
  &                       (/'X (km)', 'Y (km)'/),  &
  &                       (/'(f6.1)', '(f6.1)'/),  &
  &                       c_num=(/10, 80/), no_tone=.true. )

  call Dcl_2D_cont_shade( 'Use-Cart',  &
  &                       x, y, val3, val2,  &
  &                       (/contmin, contmax/), (/cmin, cmax/),  &
  &                       (/'X (km)', 'Y (km)'/),  &
  &                       (/'(f6.1)', '(f6.1)'/),  &
  &                       c_num=(/10, 80/), no_tone=.true. )

  call DclCloseGraphics

end program
